import QtQuick 1.1
import com.nokia.meego 1.0

Page{
    id: container

    orientationLock: PageOrientation.LockPortrait

    property string transactiontype: "NOT SET"
    property string _iconpath: "images/custom.png"
    property real iconViewerOpacity: 0

    function reset()
    {
        catInputName.text = ''
	container._iconpath = 'images/custom.png'
	imageCategory.source = container._iconpath
    }

    // define a tab bar with three buttons and link them to the content
    tools: ToolBarLayout{

        ToolIcon {

             platformStyle: ToolItemStyle {inverted: true}
             iconId: "toolbar-back" ;

             onClicked: { pageStack.pop() }
        }
    }

    MouseArea{
	anchors.fill: parent

	onClicked: console.log("")
    }

    Item{
        anchors.fill: parent

//        color: "snow"
//        border.color: "grey"
//        border.width: 2
//        radius: 5

        Column{
            id: column1
            anchors.right: parent.right
            anchors.rightMargin: 6
            anchors.left: parent.left
            anchors.leftMargin: 6
            anchors.verticalCenter: parent.verticalCenter
            spacing: 6

            Text{
                text: qsTr("New category")
                anchors.horizontalCenter: parent.horizontalCenter
                color: "white"
                font.pointSize: 20
            }

            Text{
                text: qsTr("Type a name below")
                anchors.horizontalCenter: parent.horizontalCenter
                color: "white"
                font.pointSize: 20
            }

            Row{
                height: 60
                anchors.right: parent.right
                anchors.rightMargin: 0
                anchors.left: parent.left
                anchors.leftMargin: 0
                spacing: 6

                Rectangle{
                    border.color: "lightgrey"
                    radius: 6
                    width: parent.width
                    height: parent.height

                    TextInput{
                        id: catInputName
                        text: ""
                        anchors.fill: parent
                        anchors.topMargin: parent.height/2 - font.pointSize
                        anchors.leftMargin: 6
                        anchors.rightMargin: 6
                        anchors.bottomMargin: 6
                        font.pointSize: 20

                        Keys.onReturnPressed: {
                            catInputName.closeSoftwareInputPanel();
                        }
                        Keys.onEnterPressed: {
                            catInputName.closeSoftwareInputPanel();
                        }

                    }
                }
            }

            Row {
                id: row2
                x: 0
                height: 60
                anchors.horizontalCenter: parent.horizontalCenter
                spacing: 10

                Text {
                    id: text1
                    text: qsTr("Tap on the icon to edit")
                    horizontalAlignment: Text.AlignHCenter
                    anchors.verticalCenter: parent.verticalCenter
                    color: "white"
                    font.pointSize: 20
                }

                Rectangle{
                    id: imageRect

                    width: 60
                    height: 60
                    radius: 30

                    MouseArea{
                        anchors.fill: parent

                        onClicked: container.state = "IconViewer"
                    }

                    Image {
                        id: imageCategory
                        width: 42
                        height: 42
                        smooth: true
                        anchors.centerIn: parent
                        source: container._iconpath
                    }
                }
            }

            Row {
                id: row1
                y: 227
                height: 70
                anchors.horizontalCenter: parent.horizontalCenter
                spacing: 10

                Button{
                    id: updateButton
                    text: qsTr("Save")

                    onClicked: {
                        catInputName.closeSoftwareInputPanel();

                        if(CategoriesModel.validateName(catInputName.text,transactiontype))
                        {
                            var id = XmlUtility.saveTransactionCategory(catInputName.text,container.transactiontype, container._iconpath);
                            if(id !== 0)
                                CategoriesModel.addTransactionCategory(id,catInputName.text,container.transactiontype, container._iconpath);
                            else
                                console.log('an error occured');

                            pageStack.pop();
                            if(transactiontype === "expenses")
                                universalExpensesModel.reload();
                            else
                                universalIncomeModel.reload();
                        }
                        else
                        {
                            errorDialog.text = 'There is already another category named : ' + catInputName.text + '.<br/>Please type a different name and try again.'
                            errorDialog.show();
                        }
                    }
                }
            }
        } 
    }

    IconViewer{
        id: iconViewer
        anchors.fill: parent
        anchors.bottomMargin: 6
        anchors.topMargin: 6
        anchors.leftMargin: 6
        anchors.rightMargin: 6
        opacity: container.iconViewerOpacity
        focus: true

        onSelected: { imageCategory.source = iconpath; container._iconpath = iconpath; container.state = '' }
    }

    //     Visual is an item that defines some constants for the application
    //     look and feel, e.g. the font sizes & colors etc.
        Visual {
            id: visual
        }

    ModalDialog {
        id: errorDialog

        // Shown text can be set by modifying "text" property.
        text: 'name exists please select another name'

        // Always remember to define the size for the dialog.
        anchors.fill: parent

        showCancelButton: false

        z: 20

        // Demonstrating how one could keep application wide variables saved
        // in one place and use them conveniently all around the application.
        fontName: visual.defaultFontFamily
        fontColor: visual.defaultFontColor
        fontColorButton: visual.defaultFontColorButton
        fontSize: visual.defaultFontSize

        onAccepted: {
            // When dialog is accepted, e.g. the data model could be updated.
            // Just debug print here to show how to use the ModalDialog signals.
        }
    }

    states: [
        State {
            name: "IconViewer"

         PropertyChanges {
             target: column1
             opacity: 0
         }

         PropertyChanges {
             target: container
             iconViewerOpacity: 1

         }
        }
    ]

    Component.onCompleted: theme.inverted = true
}
