import QtQuick 1.1
import com.nokia.meego 1.0

Page{
    id: container

    orientationLock: PageOrientation.LockPortrait

    property real iconViewerOpacity: 0
    property XmlListModel m_tmodel
    property string transactiontype: "NOT SET"
    property string _iconpath: "images/custom.png"

    function reset()
    {
        newNameTextInput.text = ''
        categoryreelEdit.update()
	_iconpath = manager.getCategoryIcon(categoryreelEdit.m_model.get(categoryreelEdit.cIndex).id)
    }

    // define a tab bar with three buttons and link them to the content
    tools: ToolBarLayout{

        ToolIcon {

             platformStyle: ToolItemStyle {inverted: true}
             iconId: "toolbar-back" ;

             onClicked: { pageStack.pop() }
        }
    }

    MouseArea{
	anchors.fill: parent

	onClicked: console.log("")
    }

    Expenses{ id: expenses}

    Income{ id: income}

    Item{
        anchors.fill: parent

//        color: "snow"
//        border.color: "grey"
//        border.width: 2
//        radius: 5

        Column{
            id: column1
            anchors.right: parent.right
            anchors.rightMargin: 6
            anchors.left: parent.left
            anchors.leftMargin: 6
            anchors.verticalCenter: parent.verticalCenter
            spacing: 6


            Text{
                text: qsTr("Edit category")
                anchors.horizontalCenter: parent.horizontalCenter
                color: "white"

                font.pointSize: 20
            }

            Text{
                text: qsTr("Tap on a category")
                anchors.horizontalCenter: parent.horizontalCenter
                color: "white"
                font.pointSize: 20
            }

            CategoryReel{
                id: categoryreelEdit
                width: parent.width
                height: 65
                fontSize: 6
                m_model: m_tmodel

                onCIndexChanged: { container._iconpath = CategoriesModel.getCategoryIcon(m_model.get(cIndex).id); imageCategory.source = container._iconpath  }
            }

            Text{
                text: qsTr("Type new name below")
                anchors.horizontalCenter: parent.horizontalCenter
                color: "white"
                font.pointSize: 20
            }

            Row{
                height: 60
                anchors.right: parent.right
                anchors.rightMargin: 0
                anchors.left: parent.left
                anchors.leftMargin: 0
                spacing: 6

                Rectangle{
                    border.color: "lightgrey"
                    radius: 6
                    width: parent.width
                    height: parent.height

                    TextInput{
                        id: newNameTextInput
                        text: ""
                        anchors.fill: parent
                        anchors.topMargin: parent.height/2 - font.pointSize
                        anchors.leftMargin: 6
                        anchors.rightMargin: 6
                        anchors.bottomMargin: 6

                        Keys.onReturnPressed: {
                            newNameTextInput.closeSoftwareInputPanel();
                        }
                        Keys.onEnterPressed: {
                            newNameTextInput.closeSoftwareInputPanel();
                        }

                        font.pointSize: 20
                    }
                }
            }

            Row {
                id: row2
                x: 0
                height: 60
                anchors.horizontalCenter: parent.horizontalCenter
                spacing: 10

                Text {
                    id: text1
//                    width: 200
                    text: qsTr("Tap on the icon to edit")
                    horizontalAlignment: Text.AlignHCenter
                    anchors.verticalCenter: parent.verticalCenter
                    color: "white"

                    font.pointSize: 20
                }

                Rectangle{
                    id: imageRect

                    width: 60
                    height: 60
                    radius: 30

                    MouseArea{
                        anchors.fill: parent

                        onClicked: container.state = "IconViewer"
                    }

                    Image {
                        id: imageCategory
                        width: 42
                        height: 42
                        smooth: true
                        anchors.centerIn: parent
                        source: container._iconpath
                    }
                }
            }

            Button{
                id: updateButton
                text: qsTr("Save")
                width: categoryreelEdit.width

                onClicked: {
                    newNameTextInput.closeSoftwareInputPanel();

                    if(CategoriesModel.validateName(newNameTextInput.text,transactiontype))
                    {
                        if(XmlUtility.updateTransactionCategory(categoryreelEdit.getCategoryId(),newNameTextInput.text,container._iconpath,''))
                            CategoriesModel.updateTransactionCategory(categoryreelEdit.getCategoryId(),newNameTextInput.text,container._iconpath,'');

                        pageStack.pop();

                        if(transactiontype === "expenses")
                            universalExpensesModel.reload();
                        else
                            universalIncomeModel.reload();
                    }
                    else
                    {
                        errorDialog.text = 'There is already another category named : ' + newNameTextInput.text + '.<br/>Please type a different name and try again.'
                        errorDialog.show();
                    }
                }
            }
        }
    }

    IconViewer{
        id: iconViewer
        anchors.fill: parent
        anchors.bottomMargin: 6
        anchors.topMargin: 6
        anchors.leftMargin: 6
        anchors.rightMargin: 6
        opacity: container.iconViewerOpacity
        focus: true

        onSelected: { imageCategory.source = iconpath; container._iconpath = iconpath; container.state = '' }
    }

    //     Visual is an item that defines some constants for the application
    //     look and feel, e.g. the font sizes & colors etc.
    Visual {
        id: visual
    }

    ModalDialog {
        id: errorDialog

        // Shown text can be set by modifying "text" property.
        text: 'name exists please select another name'

        // Always remember to define the size for the dialog.
        anchors.fill: parent

        showCancelButton: false

        z: 20

        // Demonstrating how one could keep application wide variables saved
        // in one place and use them conveniently all around the application.
        fontName: visual.defaultFontFamily
        fontColor: visual.defaultFontColor
        fontColorButton: visual.defaultFontColorButton
        fontSize: visual.defaultFontSize

        onAccepted: {
            // When dialog is accepted, e.g. the data model could be updated.
            // Just debug print here to show how to use the ModalDialog signals.
        }
    }

    states: [
        State {
            name: "IconViewer"

            PropertyChanges {
                target: column1
                opacity: 0
            }

            PropertyChanges {
                target: container
                iconViewerOpacity: 1

            }
        }
    ]

    Component.onCompleted: theme.inverted = true

}
