import QtQuick 1.1
import com.nokia.meego 1.0

Page {
    id: expensePage

    orientationLock: PageOrientation.LockPortrait


    // define a tab bar with three buttons and link them to the content
    tools: ToolBarLayout{

        ToolIcon {

             platformStyle: ToolItemStyle {inverted: true}
             iconId: "toolbar-back" ;

            onClicked: { window.show = true; window.seconds = 6 }
        }

        ToolIcon{
            iconId: "toolbar-add"

            onClicked: {
                var component = Qt.createComponent("AddCategory.qml");
                if (component.status == Component.Ready) {
                    var page = component.createObject(expensePage);
                    page.transactiontype = "expenses";

                    pageStack.push(page);
                }
            }
        }

        ToolIcon{
            iconId: "toolbar-edit"

            onClicked: {
                var component = Qt.createComponent("EditCategory.qml");
                if (component.status == Component.Ready) {
                    var page = component.createObject(expensePage);
                    page.transactiontype = "expenses";

                    var modelcomp = Qt.createComponent("Expenses.qml");
                    if (component.status == Component.Ready) {
                        var model = modelcomp.createObject(expensePage);

                        page.m_tmodel = model;
                    }

                    pageStack.push(page);
                }
            }
        }

        ToolIcon{
            iconId: "toolbar-delete"

            onClicked: {
                var component = Qt.createComponent("RemoveCategory.qml");
                if (component.status == Component.Ready) {
                    var page = component.createObject(expensePage);
                    page.transactiontype = "expenses";

                    var modelcomp = Qt.createComponent("Expenses.qml");
                    if (component.status == Component.Ready) {
                        var model = modelcomp.createObject(expensePage);

                        page.m_tmodel = model;
                    }

                    pageStack.push(page);
                }
            }
        }

        ToolIcon {
            iconId: "toolbar-view-menu"
            platformStyle: ToolItemStyle {inverted: true}

            // the options toolbutton is visible only in the startup page
//            visible: pageStack.depth === 1? true: false

            // when clicked , the opacity of the board game is changed in order to hide images and
            // avoid cheating when playing, because if the images are shown then the user could
            // be able to pause the game and notice the differences
            onClicked: { if( myMenu.status == DialogStatus.Closed){ myMenu.open(); } else{ myMenu.close();} }

        }
    }


    // Create a menu with different menu items.
     Menu {
         id: myMenu

         // visualParent is needed to specify the grayed out area.
         visualParent: pageStack
         MenuLayout {
             MenuItem {platformStyle: MenuItemStyle {inverted: true} text: "Income"; onClicked: { pageStack.push(Qt.resolvedUrl("IncomePage.qml")); } }
             MenuItem {platformStyle: MenuItemStyle {inverted: true} text: "Tools"; onClicked: { TransactionsModel.initialize(); pageStack.push(Qt.resolvedUrl("ToolsPage.qml")); } }
             MenuItem {platformStyle: MenuItemStyle {inverted: true} text: "Share"; onClicked: {
                     var component = Qt.createComponent('PageShare.qml');
                     if(component.status == Component.Ready)
                     {
                         var page = component.createObject(expensePage);

                         page.orientationLock = PageOrientation.LockPortrait

                         page.facebook_feed_app_id = "158894497545476";
                         page.facebook_feed_picture = "http://idealapps.gr/wp-content/uploads/2011/07/MAPromotionaMobileBanner.png&h=75&w=75&zc=1"
                         page.facebook_feed_name = "MyAccountant";
                         page.facebook_feed_caption = "MyAccountant";
                         page.facebook_feed_description = "A utility application for Nokia mobile devices";

                         page.email_body = "Hey! Using MyAccountant was brilliant!check out MyAccountant at Nokia store \n http://store.ovi.com/publisher/ideal apps/"
                         page.email_subject = "MyAccountant"

                         page.toolbarvisible = true;

                         page.twitter_tweet_inreplyto = "144795056447045634";

                         pageStack.push(page);
                     }
                     else
                         console.log(component.errorString())
                 }
             }
             MenuItem {platformStyle: MenuItemStyle {inverted: true} text: "About"; onClicked: { pageStack.push(Qt.resolvedUrl("PageAbout.qml")) } }
             MenuItem {platformStyle: MenuItemStyle {inverted: true} text: "Help"; onClicked: { pageStack.push(Qt.resolvedUrl("HelpPage.qml")) } }
         }

         onStatusChanged: {
             if(myMenu.status === DialogStatus.Closed){
                 // if the menu opened while playing then the state of the pagegameboard would 'Level'
                 // and the depth of the stack would be 1
                 // if yes resume the game, if no pause the game
                 if(pageStack.depth == 1 )
                 {
                     console.log('resumed the app')
                 }
             }
         }
     }

    Component {
         id: appHighlight
         Rectangle { width: 80; height: 80; color: "lightsteelblue" }
    }

    Component{
        id: headerView
        Rectangle{
            height: 40
            color: "grey"
            width: categoriesView.width - 5
            x: categoriesView.x  - 4
            y:0
            radius: 6

            Text {
                id: detailsTitle
                text: qsTr("Categories of expenses")
                font.pointSize: 20
                color: "#FFFFFF"
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
            }
        }
    }

    GridView{
        id: categoriesView
        anchors.fill: parent
        anchors.margins: 6
        highlight: appHighlight
        header: headerView
        focus: true

        cellHeight: 110
        cellWidth: 154

        model: universalExpensesModel

        delegate: CategoryDelegate{ }
    }

    Expenses{id: universalExpensesModel }

    Component.onCompleted: theme.inverted = true
}
