import QtQuick 1.1
import QtWebKit 1.0
import com.nokia.meego 1.0

Page {
    id: googleCharts
    signal closed

    orientationLock: PageOrientation.LockPortrait

    property string mode: "NOT SET"

    property bool loading: false

    function reset()
    {
	googleChartsManager.resetList()
    }

    // define a tab bar with three buttons and link them to the content
    tools: ToolBarLayout{

        ToolIcon {

             platformStyle: ToolItemStyle {inverted: true}
             iconId: "toolbar-back" ;

             onClicked: { pageStack.pop() }
        }
    }

    ListModel{
        id: modeModel

        ListElement {
             name: "Pie Charts"
             icon: "images/pie-chart-icon.png"
             iid: "PieCharts"
         }
         ListElement {
             name: "Bar Charts"
             icon: "images/chart_bar.png"
             iid: "BarCharts"
         }
         ListElement {
             name: "Line Charts"
             icon: "images/line_chart.png"
             iid: "LineCharts"
         }
    }

    Component {
         id: modeDelegate

         Rectangle{
             width: modeView.width
             height: 60
             border.color: "snow"
             radius: 5
             color: "black"

             Row {
                 anchors.horizontalCenter: parent.horizontalCenter
                 spacing: 10
                 Text { text: name; color: "white"; font.pointSize: 20; anchors.verticalCenter: parent.verticalCenter }
                 Image{ width: 48; height: 48; smooth: true; source: icon}
             }

             MouseArea{
                 anchors.fill: parent
                 onClicked: {
                     if(iid === "PieCharts")
                         pageStack.push(Qt.resolvedUrl("GooglePieChartWizzard.qml"));
                     else if(iid === "BarCharts")
                         pageStack.push(Qt.resolvedUrl("GoogleBarChartWizzard.qml"));
                     else if(iid === "LineCharts")
                         pageStack.push(Qt.resolvedUrl("GoogleLineChartWizzard.qml"));
                 }
             }
         }
     }

    Rectangle{
        color: "black"
        radius: 5

        anchors.fill: parent

        Item{
            id: firstPage

            anchors.fill: parent

            Text{
                id: header
                color: "#ffffff"
                text: qsTr("Charts Gallery") + "<br/>" + qsTr("Tap on an item to select it")
                 horizontalAlignment: Text.AlignHCenter
                 anchors.top: parent.top
                 anchors.topMargin: 4
                 anchors.horizontalCenter: parent.horizontalCenter
                font.pointSize: 20

            }

             ListView {
                 id: modeView
                 anchors.top: header.bottom
                 anchors.bottom: parent.bottom
                 anchors.left: parent.left
                 anchors.right: parent.right
                 anchors.margins: 20
                 model: modeModel
                 spacing: 6
                 delegate: modeDelegate
             }
        }
    }

    Connections{
	target: googleChartsManager
        onFinished: { googleCharts.loading = true; web.html = htmlString; googleCharts.state = 'Viewer'  }
    }

    Item{
	id: viewer
        opacity: 0
        anchors.fill: parent

	Flickable {
	    id: manual
            width: parent.width
            anchors.top: parent.top
            anchors.bottom: wizzardButton.top

            contentHeight: parent.height * 4
            contentWidth: parent.width * 1.5

	    WebView{
		id: web
		html: ""
		anchors.fill: parent

                onLoadFinished: googleCharts.loading = false
	    }

            PinchArea {
               id: pincharea

               property double __oldZoom

               pinch.minimumScale: 1
               pinch.maximumScale: 10.0

               anchors.fill: parent

               function calcZoomDelta(zoom, percent) {
                  return zoom + Math.log(percent)/Math.log(2)
               }

               onPinchStarted: {
                  __oldZoom = manual.scale
               }

               onPinchUpdated: {
                  manual.scale = calcZoomDelta(__oldZoom, pinch.scale)
               }

               onPinchFinished: {
                  manual.scale = calcZoomDelta(__oldZoom, pinch.scale)
               }
            }
	}

	Button{
	    id: wizzardButton

	    anchors.horizontalCenter: parent.horizontalCenter
	    anchors.bottom: parent.bottom
            text: qsTr("Start again")

            onClicked: { googleCharts.reset(); googleCharts.state = ''}
	}
    }

    WaitIndicator {
	id: waitIndicator

	// Always define the size for the WaitIndicator.
	anchors.fill: parent

	// Start showing the WaitIndicator immediately.
	// Otherwise it'll wait for one second before starting the indicator.
	delay: 0

	// Make sure it's on top of everything, so that the
	// Fader will capture key clicks
	z: 120

	// In real application, the WaitIndicator could be bound to
	// some "loading" appState variable etc.
        show: googleCharts.loading
    }
    states: [
        State {
            name: "Viewer"

            PropertyChanges {
                target: viewer
                opacity: 1
            }
        }
    ]

    Component.onCompleted: theme.inverted = true
}
