import QtQuick 1.1
import com.nokia.meego 1.0

Page {
    id: wizzard

    property real secondPageOpacity: 0

    property int period: -1

    signal submitted

    signal closed

    orientationLock: PageOrientation.LockPortrait

    function reset(){
	for(var i = 0; i < categoryView.count; i++)
	{
	    categoryView.currentIndex = i
	    categoryView.currentItem.reset()
	}

	categoryView.currentIndex = 0;
    }

    function selectAll()
    {
	for(var i = 0; i < categoryView.count; i++)
	{
	    categoryView.currentIndex = i
	    categoryView.currentItem.select()
	}

	categoryView.currentIndex = 0;
    }

    function clearAll()
    {
	for(var i = 0; i < categoryView.count; i++)
	{
	    categoryView.currentIndex = i
	    categoryView.currentItem.clearSelection()
	}

	categoryView.currentIndex = 0;
    }

    // define a tab bar with three buttons and link them to the content
    tools: ToolBarLayout{

        ToolIcon {

             platformStyle: ToolItemStyle {inverted: true}
             iconId: "toolbar-back" ;

             onClicked: { pageStack.pop() }
        }
    }

    Rectangle{
        color: "black"

        anchors.fill: parent

        Item{
            id: firstPage

            anchors.fill: parent

            Item{
                anchors.top: parent.top
                anchors.bottom: buttonFrame.top
                anchors.horizontalCenter: parent.horizontalCenter
                width: parent.width - 50
                anchors.verticalCenter: firstPage.verticalCenter

                Column{
                    spacing: 10
                    anchors.verticalCenter: parent.verticalCenter
                    width: parent.width

                    Text{
                        id: text1
                        text: qsTr("Select period")
                        anchors.horizontalCenter: parent.horizontalCenter

                        font.pointSize: 20
                        color: "white"
                    }

                    PeriodReel{
                        id: periodReel
                        width: parent.width - 10
                        height: 60
                        fontSize: 11
                    }
                }
            }

            Row{
                id: buttonFrame
                height: 60
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.bottom: parent.bottom

                Button{
                    id: forwButton
                    width: 160
                    height: parent.height

                    text: qsTr("Forward")

                    onClicked: wizzard.state = 'SecondPage'
                }
            }
        }

        Item{
            id: secondPage
            visible: false

            anchors.fill: parent

            opacity: wizzard.secondPageOpacity

            Categories{
                id: categoriesModel
            }

            Component{
                id: headerView
                Rectangle{
                    height: 40
                    color: "grey"
                    width: categoryView.width
                    x: categoryView.x
                    y:0
                    radius: 3

                    Text {
                        id: detailsTitle
                        text: qsTr("Categories")
                        font.pointSize: 20
                        color: "#FFFFFF"
                        anchors.horizontalCenter: parent.horizontalCenter
                        anchors.verticalCenter: parent.verticalCenter
                    }
                }
            }

            GridView{
                id: categoryView
                anchors.top: parent.top
                anchors.bottom: buttomFrame_.top
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.margins: 5
                cellWidth: 225
                cellHeight: 100
                header: headerView
                model: categoriesModel
                delegate: GoogleChartsCategoryDelegate{
                    width: 215
                    height: 90
                }
            }

            ScrollDecorator{
                flickableItem: categoryView
                z: 4
            }

            Row{
                id: buttomFrame_
                height: 60
                width: parent.width - 10
                anchors.bottom: parent.bottom
                anchors.horizontalCenter: parent.horizontalCenter

                Button{
                    id: backButton_
                    width: parent.width / 4
                    text: qsTr("Back")

                    onClicked: wizzard.state = ''
                }

                Button{
                    id: allButton_
                    width: parent.width / 4
                    text: qsTr("All")

                    onClicked: wizzard.selectAll()
                }

                Button{
                    id: noneButton_
                    width: parent.width / 4
                    text: qsTr("None")

                    onClicked: wizzard.clearAll()
                }

                Button{
                    id: forwButton_
                    width: parent.width / 4

                    text: qsTr("Finish")

                    onClicked: { googleChartsManager.setupHtml('LineCharts',periodReel.getCurrentIndex());  pageStack.pop(); }
                }
            }
        }
    }


    states: [
	State {
	    name: "SecondPage"

	    PropertyChanges {
		target: wizzard
		secondPageOpacity: 1
	    }

	     PropertyChanges {
		 target: firstPage
		visible: false
		 opacity: 0
	     }

	     PropertyChanges {
		 target: text1
		 horizontalAlignment: "AlignLeft"
	     }

      PropertyChanges {
	  target: secondPage
	  visible: true
      }
	}
    ]

    Component.onCompleted: theme.inverted = true

}
