import QtQuick 1.1
import com.nokia.meego 1.0

Page {
    id: historyPage

    orientationLock: PageOrientation.LockPortrait

    property int currentTransactionId: 0

    // define a tab bar with three buttons and link them to the content
    tools: ToolBarLayout{

        ToolIcon {

             platformStyle: ToolItemStyle {inverted: true}
             iconId: "toolbar-back" ;

             onClicked: { pageStack.pop() }
        }

        ToolIcon{
            iconId: "toolbar-edit"

            onClicked: {
                var component = Qt.createComponent("TransactionEditForm.qml");
                if (component.status == Component.Ready) {
                    var page = component.createObject(historyPage);
                    page.trId       = currentTransactionId
                    page.desc       = TransactionsModel.tDescription(currentTransactionId)
                    page.cat        = TransactionsModel.tCategory(currentTransactionId)
                    page.catIcon    = TransactionsModel.tCategoryIcon(currentTransactionId)
                    page.tDate      = TransactionsModel.tDate(currentTransactionId)
                    page.val        = TransactionsModel.tValue(currentTransactionId)

                    page.selectCategory();

                    page.tYear = TransactionsModel.tYear(currentTransactionId)
                    page.tMonth = TransactionsModel.tMonth(currentTransactionId)
                    page.tDay = TransactionsModel.tDay(currentTransactionId)

                    page.setupDateDialog();

                    pageStack.push(page);
                }
            }
        }

        ToolIcon{
            iconId: "toolbar-delete"

            onClicked: {
                dialog.show()
            }
        }
    }

    Component {
         id: appHighlight
         Rectangle { x: transactionView.x-2; y:transactionView.y; width: transactionView.width; height: 70; color: "lightgrey"; opacity: 0.5; radius: 10 }
    }

    Component{
        id: headerView
        Rectangle{
            height: 40
            color: "grey"
            width: transactionView.width
            x: transactionView.x
            y:0
            radius: 3

            Text {
                id: detailsTitle
                text: qsTr("Transactions History")
                font.pointSize: 20
                color: "#FFFFFF"
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
            }
        }
    }

    Item{
        id: historyRect
        anchors.fill: parent

        ListView {
            id: transactionView
            model: TransactionsModel
            anchors.fill: parent
            highlight: appHighlight
            highlightMoveDuration: 200
            header: headerView
            delegate: TransactionDelegate{ }
        }

        ScrollDecorator {
            flickableItem: transactionView
        }
    }

    // Visual is an item that defines some constants for the application
    // look and feel, e.g. the font sizes & colors etc.
    Visual {
        id: visual
    }

    // Example on using ModalDialog component.
    ModalDialog {
        id: dialog

        // Shown text can be set by modifying "text" property.
        text: "Click OK to delete the transaction, or click Cancel to close the dialog."

        // Always remember to define the size for the dialog.
        anchors.fill: parent

        // Demonstrating how one could keep application wide variables saved
        // in one place and use them conveniently all around the application.
        fontName: visual.defaultFontFamily
        fontColor: visual.defaultFontColor
        fontColorButton: visual.defaultFontColorButton
        fontSize: visual.defaultFontSize

        onAccepted: {
            // When dialog is accepted, e.g. the data model could be updated.
            // Just debug print here to show how to use the ModalDialog signals.

            if(XmlUtility.removeTransaction(currentTransactionId))
                TransactionsModel.removeTransaction(currentTransactionId);
            else
                console.log('an error occured')

        }
        onCancelled: {

        }
    }

    Component.onCompleted: theme.inverted = true
}
