import QtQuick 1.1
import com.nokia.meego 1.0

Page{
    id: container

    orientationLock: PageOrientation.LockPortrait

    property XmlListModel m_tmodel
    property string transactiontype: "NOT SET"

    function reset()
    {
        categoryreel.update()
    }

    // define a tab bar with three buttons and link them to the content
    tools: ToolBarLayout{

        ToolIcon {

             platformStyle: ToolItemStyle {inverted: true}
             iconId: "toolbar-back" ;

             onClicked: { pageStack.pop() }
        }
    }

    MouseArea{
	anchors.fill: parent

	onClicked: console.log("")
    }

    Expenses{ id: expenses}

    Income{ id: income}

    Item{
        anchors.fill: parent

        Column{
            id: column1
            anchors.verticalCenterOffset: 0
            anchors.right: parent.right
            anchors.rightMargin: 6
            anchors.left: parent.left
            anchors.leftMargin: 6
            anchors.verticalCenter: parent.verticalCenter
            spacing: 6

            Text{
                text: qsTr("Delete category")
                anchors.horizontalCenter: parent.horizontalCenter
                color: "white"
                font.pointSize: 20
            }

            Text {
                id: text1
                text: qsTr("Tap on the category")
                color: "white"
                anchors.horizontalCenter: parent.horizontalCenter
                font.pointSize: 20
            }

            CategoryReel{
                id: categoryreel
                y: 0
                height: 65
                anchors.right: parent.right
                anchors.rightMargin: 0
                anchors.left: parent.left
                anchors.leftMargin: 0
                m_model: m_tmodel
                fontSize: 6
            }

            Button{
                id: removeButton
                text: qsTr("Remove")
                width: categoryreel.width
                anchors.horizontalCenter: parent.horizontalCenter

                onClicked: { deleteDialog.show() }
            }

        }
    }

    // Visual is an item that defines some constants for the application
    // look and feel, e.g. the font sizes & colors etc.
    Visual {
        id: visual
    }

    ModalDialog {
        id: deleteDialog

        // Shown text can be set by modifying "text" property.
        text: qsTr("Click OK to Accept to delete category. To send it away, click Cancel.")

        // Always remember to define the size for the dialog.
        anchors.fill: parent

        z: 20

        // Demonstrating how one could keep application wide variables saved
        // in one place and use them conveniently all around the application.
        fontName: visual.defaultFontFamily
        fontColor: visual.defaultFontColor
        fontColorButton: visual.defaultFontColorButton
        fontSize: visual.defaultFontSize

        onAccepted: {
            // When dialog is accepted, e.g. the data model could be updated.
            // Just debug print here to show how to use the ModalDialog signals.

            if(TransactionsModel.categoryIntegrityCheck(categoryreel.getCategoryId()))
            {
                if(XmlUtility.removeTransactionCategory(categoryreel.getCategoryId()))
                    CategoriesModel.removeTransactionCategory(categoryreel.getCategoryId());

                pageStack.pop();

                if(transactiontype === "expenses")
                    universalExpensesModel.reload();
                else
                    universalIncomeModel.reload();
            }
            else
                infodialog.show();

        }
        onCancelled: {
            console.log("Dialog cancelled signal received.");
        }
    }

    // Example on using ModalDialog component.
    ModalDialog {
        id: infodialog

        // Shown text can be set by modifying "text" property.
        text: qsTr("Could not delete category. This category contains transactions, please delete transactions first and then try again. Click OK to continue.")

        // Always remember to define the size for the dialog.
        anchors.fill: parent

        showCancelButton: false

        // Demonstrating how one could keep application wide variables saved
        // in one place and use them conveniently all around the application.
        fontName: visual.defaultFontFamily
        fontColor: visual.defaultFontColor
        fontColorButton: visual.defaultFontColorButton
        fontSize: visual.defaultFontSize

        onAccepted: {
            // When dialog is accepted, e.g. the data model could be updated.
            // Just debug print here to show how to use the ModalDialog signals.

        }
    }

    Component.onCompleted: theme.inverted = true
}
