import QtQuick 1.1
import com.nokia.meego 1.0

Page {
    orientationLock: PageOrientation.LockPortrait
    id: container

    signal finished

    property string currentPath: "NOT SET"


    // define a tab bar with three buttons and link them to the content
    tools: ToolBarLayout{

        ToolIcon {

             platformStyle: ToolItemStyle {inverted: true}
             iconId: "toolbar-back" ;

             onClicked: { pageStack.pop() }
        }

        ToolIcon{
            iconId: "toolbar-delete"

            onClicked: {
                questionDialog2.show()
            }
        }

        ToolIcon{
            iconId: "toolbar-update"

            onClicked: questionDialog.show()
        }

    }

    Component{
        id: highlightView
        Rectangle{
            width: restoreView.width
            height: 64
            x: restoreView.currentItem.x - 4
            y: restoreView.currentItem.y - 2

            color: "orange"
        }
    }

    Component{
        id: headerView
        Rectangle{
            height: 30
            color: "grey"
            width: restoreView.width - 3
            x: restoreView.x  - 4
            y:0
            radius: 3

            Text {
                id: detailsTitle
                text: qsTr("Restorable backup copies")
                font.pointSize: 20
                color: "#FFFFFF"
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
            }
        }
    }

    Component{
        id: restoreDelegate
        Item{
            width: restoreView.width-10
            height: 60

            Rectangle{
                id: background
                anchors.fill: parent
                anchors.margins: 3
                color: "transparent"
                border.color: "grey"
                border.width: 2
                radius: 5
            }

            Row{
                id: upperFrame
                spacing: 6
                anchors { left: parent.left; right: parent.right; top: parent.top; margins: 6 }
                height: 30

                Text{
                    text: name
                    color: "white"
                    font.pointSize: 18
                    anchors.verticalCenter: parent.verticalCenter
                }

                Text{

                    text: date
                    font.pointSize: 15
                    wrapMode: Text.WordWrap
                    color: "white"
                    anchors.verticalCenter: parent.verticalCenter
                }
            }

            Text{
                id: lowerFrame
                anchors{ left: parent.left; right: parent.right; top: upperFrame.bottom; margins: 6 }
                text: path
                width: parent.width
                font.pointSize: 11
                wrapMode: Text.WordWrap
                color: "grey"
            }

            MouseArea{
                anchors.fill: parent
                onClicked: { restoreView.currentIndex = index; currentPath = path }
            }
        }
    }

    Connections{
        target: XmlUtility
        onRestoreFinished: infoDialog.show()
    }


    Item{
        anchors.fill: parent

        Text{
            id: label
            anchors.top: parent.top
            anchors.topMargin: 8
            anchors.horizontalCenter: parent.horizontalCenter
            text: qsTr("Tap on a backup copy first !")
            font.bold: true
            color: "white"
            font.pointSize: 20
        }

        ListView{
            id: restoreView
            width: parent.width - 10
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: label.bottom
            anchors.topMargin: 6
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 6
            model: RestoreModel
            delegate: restoreDelegate
            header: headerView
            highlight: highlightView
        }
    }

    //     Visual is an item that defines some constants for the application
    //     look and feel, e.g. the font sizes & colors etc.
        Visual {
            id: visual
        }

        ModalDialog {
            id: questionDialog

            // Shown text can be set by modifying "text" property.
            text: "Click OK to restore the database. Click Cancel to close the dialog"

            // Always remember to define the size for the dialog.
            anchors.fill: parent

            z: 20

            // Demonstrating how one could keep application wide variables saved
            // in one place and use them conveniently all around the application.
            fontName: visual.defaultFontFamily
            fontColor: visual.defaultFontColor
            fontColorButton: visual.defaultFontColorButton
            fontSize: visual.defaultFontSize

            onAccepted: {
                // When dialog is accepted, e.g. the data model could be updated.
                // Just debug print here to show how to use the ModalDialog signals.
                XmlUtility.restore(container.currentPath)
            }

            onCancelled: {
            }
        }

        ModalDialog {
            id: questionDialog2

            // Shown text can be set by modifying "text" property.
            text: "Click OK to delete the backup copy file. Click Cancel to close the dialog"

            // Always remember to define the size for the dialog.
            anchors.fill: parent

            z: 20

            // Demonstrating how one could keep application wide variables saved
            // in one place and use them conveniently all around the application.
            fontName: visual.defaultFontFamily
            fontColor: visual.defaultFontColor
            fontColorButton: visual.defaultFontColorButton
            fontSize: visual.defaultFontSize

            onAccepted: {
                // When dialog is accepted, e.g. the data model could be updated.
                // Just debug print here to show how to use the ModalDialog signals.
                RestoreModel.deleteAndRemoveItem(container.currentPath)
            }

            onCancelled: {
            }
        }

        ModalDialog {
            id: infoDialog

            // Shown text can be set by modifying "text" property.
            text: "Restore finished successfully! a restart is needed! click OK to exit the application."

            // Always remember to define the size for the dialog.
            anchors.fill: parent

            showCancelButton: false

            z: 20

            // Demonstrating how one could keep application wide variables saved
            // in one place and use them conveniently all around the application.
            fontName: visual.defaultFontFamily
            fontColor: visual.defaultFontColor
            fontColorButton: visual.defaultFontColorButton
            fontSize: visual.defaultFontSize

            onAccepted: {
                // When dialog is accepted, e.g. the data model could be updated.
                // Just debug print here to show how to use the ModalDialog signals.
                Qt.quit()
            }
        }
}

