import QtQuick 1.1
import com.nokia.meego 1.0
import StatsWidget 1.0

Page {
    id: container

    orientationLock: PageOrientation.LockPortrait

    property real restoreOpacity : 0
    property real historyOpacity: 0
    property real queryOpacity: 0
    property real googleChartsOpacity: 0

    function updateStats()
    {
        textBalance.text = TransactionsModel.getBalance()
        textLastWeekExpenses.text = TransactionsModel.getLastWeekExpensesString()
        textLastMonthExpenses.text = TransactionsModel.getLastMonthExpensesString()
        textAllExpenses.text = TransactionsModel.getAllExpensesString()
        textLastWeekIncome.text = TransactionsModel.getLastWeekIncomeString()
        textLastMonthIncome.text = TransactionsModel.getLastMonthIncomeString()
        textAllIncome.text = TransactionsModel.getAllIncomeString()
    }

    // define a tab bar with three buttons and link them to the content
    tools: ToolBarLayout{

        ToolIcon {

             platformStyle: ToolItemStyle {inverted: true}
             iconId: "toolbar-back" ;

             onClicked: { pageStack.pop() }
        }
    }

    Image{
        source: "images/graph_paper.png"
        width: upperFrame.width
        height: upperFrame.height
        x: upperFrame.x
        y: upperFrame.y
    }

    Item{
        id: upperFrame
        anchors.top: parent.top
        anchors.topMargin: 6
        anchors.horizontalCenter: parent.horizontalCenter
        width: infoColumn.width + 40
        height: infoColumn.height + 40

        Column{
            id: infoColumn
            anchors.centerIn: parent
            spacing: 6

            Text{
		text: qsTr("Statistics")
                font.pointSize: 20
                font.bold: true
                anchors.horizontalCenter: parent.horizontalCenter
            }

            Row{
                spacing: 6

                Text {
                    id: text1
		    text: qsTr("Account balance : ")
                    font.pointSize: 20
                }

                Text {
		    id: textBalance
                    text: TransactionsModel.getBalance()
                    font.pointSize: 20
		    color: text > 0.0? "blue": "red"
                }
            }

            Row{
                spacing: 6

                Text{
		    text: qsTr("Expenses this week : ")
                    font.pointSize: 20
                }

                Text{
		    id: textLastWeekExpenses
                    text: TransactionsModel.getLastMonthExpensesString()
                    font.pointSize: 20
                    color: "red"
                }
            }

            Row{
                spacing: 6

                Text{
		    text: qsTr("Expenses this month : ")
                    font.pointSize: 20
                }

                Text{
		    id: textLastMonthExpenses
                    text: TransactionsModel.getLastMonthExpensesString()
                    font.pointSize: 20
                    color: "red"
                }
            }

            Row{
                spacing: 6

                Text{
		    text: qsTr("Expenses total : ")
                    font.pointSize: 20
                }

                Text{
		    id: textAllExpenses
                    text: TransactionsModel.getLastWeekExpensesString()
                    font.pointSize: 20
                    color: "red"
                }
            }

            Row{
                spacing: 6

                Text{
		    text: qsTr("Income this week : ")
                    font.pointSize: 20
                }

                Text{
		    id: textLastWeekIncome
                    text: TransactionsModel.getLastWeekIncomeString()
                    font.pointSize: 20
                    color: "blue"
                }
            }

            Row{
                spacing: 6

                Text{
		    text: qsTr("Income this month : ")
                    font.pointSize: 20
                }

                Text{
		    id: textLastMonthIncome
                    text: TransactionsModel.getLastMonthIncomeString()
                    font.pointSize: 20
                    color: "blue"
                }
            }

            Row{
                spacing: 6

                Text{
		    text: qsTr("Income total : ")
                    font.pointSize: 20
                }

                Text{
		    id: textAllIncome
                    text: TransactionsModel.getAllIncomeString()
                    font.pointSize: 20
                    color: "blue"
                }
            }
        }
    }

    VisualItemModel{
        id: buttonModel

        Button {
            id: toolbuttonHistory
            text: qsTr("History")
            iconSource: "images/Calendar.png"
            height: 70

            onClicked: { pageStack.push(Qt.resolvedUrl("HistoryPage.qml")); }
        }

//        Button {
//            id: toolButtonStats
//            text: qsTr("Stats")
//            iconSource: "images/pie-chart-icon.png"
//            height: 70

//            onClicked: { pageStack.push(Qt.resolvedUrl("StatsQueryPage.qml")); }
//        }

        Button {
            id: toolbuttonBackup
            text: qsTr("Backup")
            iconSource: "images/Backup.png"
            height: 70

            onClicked: { infoDialog.text ="Backup finished successfully! Click ok to close the dialog"; XmlUtility.backup() }
        }

        Button {
            id: toolbuttonRestore
            text: qsTr("Restore")
            iconSource: "images/restore.png"
            height: 70


            onClicked: { RestoreModel.initialize(); pageStack.push(Qt.resolvedUrl("RestoreTool.qml")); }
        }

        Button {
            id: googleChartsButton
            text: qsTr("Charts")
            iconSource: "images/google_charts.png"
            height: 70

            onClicked:  { googleChartsDialog.show(); }
        }
    }

    ListView{
        id: toolsFrame
        anchors.top: upperFrame.bottom
        anchors.topMargin: 6
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 6
        model: buttonModel
        width: upperFrame.width
        x: upperFrame.x
        interactive: false
        spacing: 6
    }

    Connections{
        target: XmlUtility
	onImportFinished: { infoDialog.text = qsTr("Import created successfully! Click ok to close the dialog"); infoDialog.show() }
        onImportFailed: { infoDialog.text = qsTr("Import failed! Click ok to close the dialog"); infoDialog.show() }
        onExportFinished: { infoDialog.text = qsTr("Export created successfully! Click ok to close the dialog"); infoDialog.show() }
        onExportFailed: { infoDialog.text = qsTr("Export failed! Click ok to close the dialog"); infoDialog.show() }
        onBackupCreated: { RestoreModel.addItem(path); infoDialog.text = qsTr("Backup finished successfully!<br/>File path follows<br/>" + path); infoDialog.show() }
    }


    Connections{
        target: TransactionsModel
        onTransactionChanged: { container.updateStats() }
    }

    // Visual is an item that defines some constants for the application
    // look and feel, e.g. the font sizes & colors etc.
    Visual {
        id: visual
    }

    ModalDialog {
        id: infoDialog

        // Shown text can be set by modifying "text" property.
	text: qsTr("Backup created successfully! Click OK to Accept to close the dialog.")

        // Always remember to define the size for the dialog.
        anchors.fill: parent

        showCancelButton: false

        z: 20

        // Demonstrating how one could keep application wide variables saved
        // in one place and use them conveniently all around the application.
        fontName: visual.defaultFontFamily
        fontColor: visual.defaultFontColor
        fontColorButton: visual.defaultFontColorButton
        fontSize: visual.defaultFontSize
//        fontSize: 10

        onAccepted: {
            // When dialog is accepted, e.g. the data model could be updated.
            // Just debug print here to show how to use the ModalDialog signals.


        }
    }


    // Example on using ModalDialog component.
    ModalDialog {
	id: googleChartsDialog

	// Shown text can be set by modifying "text" property.
	text: qsTr("Internet connection is needed!<br/>Click OK to continue, or click Cancel to close the dialog.")

	// Always remember to define the size for the dialog.
	anchors.fill: parent

	// Demonstrating how one could keep application wide variables saved
	// in one place and use them conveniently all around the application.
	fontName: visual.defaultFontFamily
	fontColor: visual.defaultFontColor
	fontColorButton: visual.defaultFontColorButton
	fontSize: visual.defaultFontSize

	onAccepted: {
	    // When dialog is accepted, e.g. the data model could be updated.
	    // Just debug print here to show how to use the ModalDialog signals.

            googleChartsManager.initialize();

            var component = Qt.createComponent("GoogleChartsViewer.qml");
            if (component.status == Component.Ready) {
                var page = component.createObject(container);

                pageStack.push(page);
            }
	}
	onCancelled: {
	}
    }

    Component.onCompleted: theme.inverted = true
}
