import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.0

Page {
    id: tdialog

    orientationLock: PageOrientation.LockPortrait

    property string catName: "NOT SET"
    property string catId: "NOT SET"
    property string tag: "NOT SET"
    property string icon: "NOT SET"
    property string icon2: "NOT SET"
    property string currentDate: Qt.formatDateTime(new Date(),'MM-dd-yyyy')

    property real messageOpacity: 0.0

    signal accepted
    signal canceled

    function reset(){
        amountTextInput.text = ''
        descriptionTextInput = ''
    }

    function setupDateDialog(){
        var d = new Date();
        dDialog.year = d.getFullYear();
        dDialog.month = (d.getMonth()+1);
        dDialog.day = d.getDate();
    }

    DatePickerDialog {
        id: dDialog
        titleText: "Date of transaction"
        onAccepted: callbackFunction()
    }

    function launchDialog() {
        dDialog.open();
    }

    function callbackFunction() {
        var d = new Date(dDialog.year,dDialog.month-1,dDialog.day);

        currentDate = Qt.formatDate(d,'MM-dd-yyyy');
    }

    // define a tab bar with three buttons and link them to the content
    tools: ToolBarLayout{

        ToolIcon {

             platformStyle: ToolItemStyle {inverted: true}
             iconId: "toolbar-back" ;

             onClicked: { pageStack.pop() }
        }
    }

    Rectangle{
        width: column.width + 30
        height: column.height + 30
        anchors.centerIn: parent
        radius: 6
        border.color: "whitesmoke"
        color:"transparent"

        Column{
            id: column
            anchors.centerIn: parent
            spacing: 6

            Row{
                spacing: 6
                anchors.horizontalCenter: parent.horizontalCenter

                Text{
                    text: qsTr("Add ") + tag
                    font.pointSize: 20
                    color: "white"
                    anchors.verticalCenter: parent.verticalCenter
                }

                Image{
                    source: icon2
                    width: 24
                    height: 24
                    smooth: true
                    anchors.verticalCenter: parent.verticalCenter
                }

                Text{
                    id: categoryText
                    text: qsTr("for ") + catName
                    color: "white"
                    font.pointSize: 20
                    anchors.verticalCenter: parent.verticalCenter
                }

                Image{
                    source: icon
                    width: 24
                    height: 24
                    smooth: true
                    anchors.verticalCenter: parent.verticalCenter
                }
            }

            Row{
                spacing: 6
                anchors.horizontalCenter: parent.horizontalCenter
                height: 60

                Text{

                    text: qsTr("Date : ") + tdialog.currentDate
                    color: "white"
                    font.pointSize: 20
                    anchors.verticalCenter: parent.verticalCenter
                }

                Button{
                    text: "Edit"
                    height: 60
                    width: 80

                    onClicked: launchDialog()
                }
            }

            Text{
                text: qsTr("Type the amount below (necessary), (please use '.' dot character as a decimal separator and ',' comma character for thousands.)")
                width: parent.width
                wrapMode: Text.WordWrap
                anchors.horizontalCenter: parent.horizontalCenter
                font.pointSize: 20
                color: "grey"
            }

            Rectangle{
                width: parent.width
                height: 60
                border.color: "#b3b3b3"
                radius: 6

                TextInput{
                    id: amountTextInput
                    text: ""
                    width: parent.width - 10
                    anchors.fill: parent
                    anchors.leftMargin: 6
                    anchors.topMargin: parent.height/2 - font.pointSize
                    validator: DoubleValidator{ bottom: 0.0; top: 1000000000000.0; decimals: 2 }
                    font.pointSize: 20
                    color: "#333333"

                    Keys.onReturnPressed: {
                        amountTextInput.closeSoftwareInputPanel();
                    }
                    Keys.onEnterPressed: {
                        amountTextInput.closeSoftwareInputPanel();
                    }
                }
            }

            Text{
                text: qsTr("Type a description below ( optional)")
                anchors.horizontalCenter: parent.horizontalCenter
                font.pointSize: 20
                color: "grey"
            }

            Rectangle{
                width: parent.width
                height: 60
                border.color: "#b3b3b3"
                radius: 6

                TextInput{
                    id: descriptionTextInput
                    text: ""
                    anchors.fill: parent
                    anchors.leftMargin: 6
                    anchors.topMargin: parent.height/2 - font.pointSize
                    width: parent.width
                    color: "#333333"
                    font.pointSize: 20

                    Keys.onReturnPressed: {
                        descriptionTextInput.closeSoftwareInputPanel();
                    }
                    Keys.onEnterPressed: {
                        descriptionTextInput.closeSoftwareInputPanel();
                    }
                }
            }

            Row{
                spacing: 6
                height: 60
                anchors.horizontalCenter: parent.horizontalCenter

                Button{
                    id: saveButton
                    text: qsTr("Save ")

                    onClicked: { amountTextInput.closeSoftwareInputPanel(); descriptionTextInput.closeSoftwareInputPanel(); dialog.show() }
                }
            }
        }
    }

    // Visual is an item that defines some constants for the application
    // look and feel, e.g. the font sizes & colors etc.
    Visual {
        id: visual
    }

    // Example on using ModalDialog component.
    ModalDialog {
        id: dialog

        // Shown text can be set by modifying "text" property.
        text: qsTr("Click OK to save the transaction, or click Cancel to close the dialog.")

        // Always remember to define the size for the dialog.
        anchors.fill: parent

        // Demonstrating how one could keep application wide variables saved
        // in one place and use them conveniently all around the application.
        fontName: visual.defaultFontFamily
        fontColor: visual.defaultFontColor
        fontColorButton: visual.defaultFontColorButton
        fontSize: visual.defaultFontSize

        onAccepted: {
            // When dialog is accepted, e.g. the data model could be updated.
            // Just debug print here to show how to use the ModalDialog signals.
//            console.log(dateReel.getDate());

            if(XmlUtility.saveTransaction(tdialog.catId,Qt.formatDate(new Date(dDialog.year,dDialog.month-1,dDialog.day),'yyyy-MM-dd'),amountTextInput.text, descriptionTextInput.text))
            {
                TransactionsModel.addTransaction(tdialog.catId,Qt.formatDate(new Date(dDialog.year,dDialog.month-1,dDialog.day),'yyyy-MM-dd'),amountTextInput.text, descriptionTextInput.text);

                amountTextInput.text = ''

                descriptionTextInput.text = ''

                pageStack.pop();
            }
            else
                console.log('an error occur');
        }
        onCancelled: { }
    }

    Component.onCompleted: theme.inverted = true
}
