import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.0

Page{
    id: container

    property int trId : 0

    property real val : 0

    property string desc: qsTr("NOT SET")

    property string cat: qsTr("NOT SET")

    property string catIcon: qsTr("NOT SET")

    property string tDate: qsTr("NOT SET")

    property int tYear: 0
    property int tMonth: 0
    property int tDay: 0

    orientationLock: PageOrientation.LockPortrait

    function selectCategory()
    {
        categoryreel.selectCategory(container.cat)
    }

    function setupDateDialog(){
        dDialog.year = tYear
        dDialog.month = tMonth
        dDialog.day = tDay
    }

    DatePickerDialog {
        id: dDialog
        titleText: "Date of transaction"
        onAccepted: callbackFunction()
    }

    function launchDialog() {
        dDialog.open();
    }

    function launchDialogToToday() {
        dDialog.open();
    }

    function callbackFunction() {
        var d = new Date(dDialog.year,dDialog.month-1,dDialog.day);

        tDate = Qt.formatDate(d,'MM-dd-yyyy');
    }

    // define a tab bar with three buttons and link them to the content
    tools: ToolBarLayout{

        ToolIcon {

             platformStyle: ToolItemStyle {inverted: true}
             iconId: "toolbar-back" ;

             onClicked: { pageStack.pop() }
        }
    }

    Rectangle{
        width: upperColumn.width + 30
        height: upperColumn.height + 50
        radius: 6
        border.color: "whitesmoke"
        anchors.centerIn: parent
        color: "transparent"

        Column{
            id: upperColumn
            spacing: 6
            anchors.centerIn: parent

            Text{
                anchors.horizontalCenter: parent.horizontalCenter
                text: qsTr("Transaction category")
                color: "white"
                font.pointSize: 20
            }

            Row{
                anchors.horizontalCenter: parent.horizontalCenter
                spacing: 10
                Image{
                    width: 32
                    height: 32
                    smooth: true
                    source: container.catIcon
                }

                Text{
                    text: container.cat
                    color: "white"
                    font.pointSize: 20
                    anchors.verticalCenter: parent.verticalCenter
                }
            }


            Row{
                spacing: 10
                anchors.horizontalCenter: parent.horizontalCenter

                Text{
                    text: qsTr("Category")
                    color: "white"
                    font.pointSize: 20

                    anchors.verticalCenter: parent.verticalCenter
                }

                CategoryReel{
                    id: categoryreel
                    height: 50
                    m_model: Categories{ onStatusChanged: { if(status == XmlListModel.Ready)selectCategory() } }
                }
            }

            Row{
                spacing: 6
                anchors.horizontalCenter: parent.horizontalCenter
                height: 60

                Text{
                    text: qsTr("Date : ") + container.tDate
                    color: "white"
                    font.pointSize: 20
                    anchors.verticalCenter: parent.verticalCenter
                }

                Button{
                    text: "Edit"
                    height: 60
                    width: 80

                    onClicked: launchDialog()
                }
            }

            Row{
                anchors.horizontalCenter: parent.horizontalCenter
                spacing: 6

                Text{
                    id: textAmount
                    text: qsTr("Amount       : ")
                    color: "white"
                    font.pointSize: 20
                    anchors.verticalCenter: parent.verticalCenter
                }

                Rectangle{
                    width: 200
                    height: 60
                    border.color: "#b3b3b3"
                    radius: 6

                    TextInput{
                        id: amountTextInput
                        text: container.val
                        anchors.fill: parent
                        anchors.topMargin: parent.height/2 - font.pointSize
                        anchors.leftMargin: 6
                        anchors.rightMargin: 6
                        font.pointSize: 20
                        color: "#333333"
                        validator: DoubleValidator{ bottom: 0.0; top: 1000000000.0; decimals: 2 }

                        Keys.onReturnPressed: {
                            amountTextInput.closeSoftwareInputPanel();
                        }
                        Keys.onEnterPressed: {
                            amountTextInput.closeSoftwareInputPanel();
                        }
                    }
                }
            }

            Row{
                anchors.horizontalCenter: parent.horizontalCenter
                spacing: 6

                Text{
                    id: textDescription
                    text: qsTr("Description : ")
                    color: "white"
                    font.pointSize: 20

                    anchors.verticalCenter: parent.verticalCenter
                }

                Rectangle{
                    id: descriptionRect
                    width: 200
                    height: 60
                    border.color: "#b3b3b3"
                    radius: 6

                    TextInput{
                        id: descriptionTextInput
                        text: container.desc
                        anchors.topMargin: height / 2 - font.pointSize
                        anchors.leftMargin: 6
                        anchors.fill: parent
                        color: "#333333"
                        font.pointSize: 20

                        Keys.onReturnPressed: {
                            descriptionTextInput.closeSoftwareInputPanel();
                        }
                        Keys.onEnterPressed: {
                            descriptionTextInput.closeSoftwareInputPanel();
                        }
                    }
                }
            }

            Button{
                text: qsTr("Save")

                width: 150
                height: 60
                anchors.horizontalCenter: parent.horizontalCenter

                onClicked:
                {
                    descriptionTextInput.closeSoftwareInputPanel();

                    if(XmlUtility.updateTransaction(trId,categoryreel.getCategoryId(), Qt.formatDate(new Date(dDialog.year,dDialog.month-1,dDialog.day),'yyyy-MM-dd'), amountTextInput.text, descriptionTextInput.text))
                        TransactionsModel.updateTransaction(trId,categoryreel.getCategoryId(), Qt.formatDate(new Date(dDialog.year,dDialog.month-1,dDialog.day),'yyyy-MM-dd'), amountTextInput.text, descriptionTextInput.text);
                    else
                        console.log('An error occured');

                    pageStack.pop();
                }
            }
        }
    }
}
